@@ -1,6 +1,8 @@
 from dataclasses import dataclass
 from functools import cached_property
+from typing import Optional
 
+from ldflex import LDFlex
 from octadocs.octiron import Octiron
 from rdflib.term import Node, URIRef
 
@@ -11,6 +13,12 @@ class Facet:
 
     iri: Node
     octiron: Octiron
+    environment: Optional[URIRef] = None
+
+    @property
+    def ldflex(self) -> LDFlex:
+        """Extract LDFLex instance."""
+        return self.octiron.ldflex
 
     @cached_property
     def uriref(self) -> URIRef:
@@ -19,9 +27,9 @@ class Facet:
 
     def query(self, query_text: str, **kwargs):
         """SPARQL query."""
-        return self.octiron.query(
+        return self.ldflex.query(
             query_text=query_text,
-            **kwargs
+            **kwargs,
         )
 
     def render(self):
