@@ -1,12 +1,11 @@
 import logging
-import re
 import sys
 from dataclasses import dataclass, field
 from enum import Enum, auto
 from functools import reduce
 from pathlib import Path
 from types import MappingProxyType
-from typing import Any, Dict, Iterable, Optional, Type
+from typing import Any, Dict, Iterable, Optional
 
 import rdflib
 from iolanta.context import merge
@@ -25,8 +24,8 @@ from octadocs.octiron.inference import (
     apply_inference_owlrl,
     apply_inference_sparql,
 )
-from octadocs.octiron.plugins import Loader, MarkdownLoader, YAMLLoader
 from octadocs.query import _format_query_bindings
+from octadocs.storage import save_graph
 from octadocs.types import DEFAULT_NAMESPACES
 from octadocs.types import LOCAL as local
 from octadocs.types import Context, QueryResult
@@ -167,42 +166,27 @@ class Octiron:  # noqa: WPS214
         elif cache_status == CacheStatus.EXPIRED:
             self.clear_named_graph(local_iri)
 
-        context = self.get_context_per_directory(path.parent)
-        loader_class = self.get_loader_class_for_path(path)
-
-        if loader_class is None:
-            try:
-                quads = as_quad_stream(
-                    url=URL(f'file://{path}'),
-                    iri=local_iri,
-                    default_context=self.root_context,
-                    root_directory=self.root_directory,
+        try:
+            quads = as_quad_stream(
+                url=URL(f'file://{path}'),
+                iri=local_iri,
+                default_context=self.root_context,
+                root_directory=self.root_directory,
+                named_contexts=named_contexts,
+            )
+        except ParserNotFound:
+            if skip_file_if_not_importable:
+                logger.info(
+                    'Cannot import %s because no loader was found.',
+                    path,
                 )
-            except ParserNotFound:
-                if skip_file_if_not_importable:
-                    logger.info(
-                        'Cannot import %s because no loader was found.',
-                        path,
-                    )
-                    return
-                else:
-                    raise
-
-            except IsAContext:
-                logger.info('Cannot parse a context, sorry')
                 return
 
-        else:
-            quads = self._legacy_get_quads(
-                cache_status=cache_status,
-                context=context,
-                global_url=global_url,
-                loader_class=loader_class,
-                local_iri=local_iri,
-                named_contexts=named_contexts,
-                path=path,
-                relative_path=relative_path,
-            )
+            raise
+
+        except IsAContext:
+            logger.info('Cannot parse a context, sorry')
+            return
 
         self.graph.addN(quads)
 
@@ -283,17 +267,6 @@ class Octiron:  # noqa: WPS214
             # Changes made by SPARQL queries might require another pass of OWL RL
             apply_inference_owlrl(graph=self.graph)
 
-    def get_loader_class_for_path(self, path: Path) -> Optional[Type[Loader]]:
-        """Based on file path, determine the loader to use."""
-        # TODO dependency inversion
-        loaders = [MarkdownLoader, YAMLLoader]
-
-        for loader in loaders:
-            if re.search(loader.regex, str(path)) is not None:
-                return loader
-
-        return None
-
     def _find_context_files(self, directory: Path) -> Iterable[Path]:
         """
         Find all context files relevant to particular directory.
@@ -343,3 +316,11 @@ class Octiron:  # noqa: WPS214
             return graph
 
         return _format_query_bindings(sparql_result.bindings)
+
+    def save_graph_to_cache(self):
+        """Pickle the graph to reuse it in CLI and other tools."""
+        save_graph(
+            graph=self.graph,
+            path=self.root_directory.parent / '.cache/octadocs',
+        )
+        logger.info('Saved graph to disk for CLI to use.')
