@@ -1,5 +1,6 @@
 import logging
 import operator
+import re
 from functools import lru_cache, partial
 from pathlib import Path
 from typing import Any, Callable, Dict, Optional
@@ -13,6 +14,8 @@ from mkdocs.structure.pages import Page
 from octadocs.conversions import iri_by_page, src_path_to_iri
 from octadocs.default_context import construct_root_context
 from octadocs.iolanta import render
+from octadocs.iolanta.errors import FacetNotFound
+from octadocs.iolanta.iolanta import Render
 from octadocs.macros import link
 from octadocs.navigation.processor import OctadocsNavigationProcessor
 from octadocs.octiron import Octiron
@@ -20,10 +23,11 @@ from octadocs.query import query
 from octadocs.storage import save_graph
 from octadocs.stored_query import StoredQuery
 from octadocs.types import DEFAULT_NAMESPACES, LOCAL, OCTA, Query
+from rdflib import URIRef
 from rich.traceback import install
 from typing_extensions import TypedDict
 
-install(show_locals=False)
+# install(show_locals=False)
 
 logger = logging.getLogger(__name__)
 
@@ -60,26 +64,6 @@ class TemplateContext(TypedDict):
     rdfs: rdflib.Namespace
 
 
-def get_template_by_page(
-    page: Page,
-    graph: rdflib.ConjunctiveGraph,
-) -> Optional[str]:
-    """Find the template to render the given Markdown file."""
-    iri = rdflib.URIRef(f'{LOCAL}{page.file.src_path}')
-
-    bindings = graph.query(
-        'SELECT ?template_name WHERE { ?iri octa:template ?template_name }',
-        initBindings={
-            'iri': iri,
-        },
-    ).bindings
-
-    if bindings:
-        return bindings[0]['template_name'].value
-
-    return None
-
-
 @lru_cache(None)
 def cached_octiron(docs_dir: Path) -> Octiron:
     """Retrieve cached Octiron instance or create it if absent."""
@@ -161,13 +145,21 @@ class OctaDocsPlugin(BasePlugin):
         """Inject page template path, if necessary."""
         page.iri = iri_by_page(page)
 
-        template_name = get_template_by_page(
-            page=page,
-            graph=self.octiron.graph,
-        )
+        try:
+            template_url = Render(
+                ldflex=self.octiron.ldflex,
+            ).find_facet_iri(
+                node=page.iri,
+                environments=[URIRef(OCTA)],
+            )
+        except FacetNotFound:
+            return markdown
 
-        if template_name is not None:
-            page.meta['template'] = template_name
+        page.meta['template'] = re.sub(
+            '^templates:',
+            '',
+            template_url,
+        )
 
         return markdown
 
@@ -269,9 +261,8 @@ class OctaDocsPlugin(BasePlugin):
 
     def on_post_build(self, config: Config):
         """Save the graph to a file on disk."""
-        docs_dir = Path(config['docs_dir'])
-        save_graph(
-            graph=self.octiron.graph,
-            path=docs_dir.parent / '.cache/octadocs',
-        )
-        logger.info('Saved graph to disk for CLI to use.')
+        self.octiron.save_graph_to_cache()
+
+    def on_build_error(self, error):
+        """Save the graph to a file on build error."""
+        self.octiron.save_graph_to_cache()
