@@ -3,7 +3,7 @@ from pathlib import Path
 from typing import Any
 
 from documented import DocumentedError
-from octadocs.query import QueryResult
+from octadocs.types import QueryResult
 from typing_extensions import Protocol
 
 
