@@ -1,6 +1,6 @@
+from dominate.tags import a, code, table, tbody, td, th, thead, tr
 from octadocs.octiron import Octiron
 from rdflib import URIRef
-from dominate.tags import table, thead, tr, th, tbody, td, code, a
 
 
 def build_table_row(status) -> tr:
