@@ -8,11 +8,10 @@ from typing import Dict, List, Optional
 from dominate import tags
 from mkdocs.structure.pages import Page
 from more_itertools import first
-from rdflib import URIRef
-from rdflib.term import Node, Literal
-
 from octadocs.iolanta import render
 from octadocs.octiron import Octiron
+from rdflib import URIRef
+from rdflib.term import Literal, Node
 
 logger = logging.getLogger(__name__)
 
