@@ -1,11 +1,18 @@
 import json
 import logging
 import operator
+import os
+from concurrent.futures import ThreadPoolExecutor
+from functools import partial
 from pathlib import Path
-from typing import Optional
+from typing import Optional, List
 
+import backoff
 import rich
-from github import Github, UnknownObjectException
+from github import Github, UnknownObjectException, RateLimitExceededException
+from github.GitRelease import GitRelease
+
+from iolanta.models import LDDocument
 from ldflex import LDFlex
 from octadocs.storage import load_graph
 from octadocs_github.models import GH, RepoDescription
@@ -60,6 +67,54 @@ def extract_repo_name(url: URL) -> Optional[str]:
     return f'{owner_name}/{repo_name}'
 
 
+@backoff.on_exception(backoff.expo, RateLimitExceededException)
+def retrieve_releases(repo) -> List[LDDocument]:
+    """Retrieve GitHub releases as a JSON document."""
+    rich.print(f'Downloading: {repo} releases...')
+    releases = repo.get_releases().reversed.get_page(0)
+    return list(map(operator.attrgetter('raw_data'), releases))
+
+
+@backoff.on_exception(backoff.expo, RateLimitExceededException)
+def retrieve_repository_description(
+    repository_name: str,
+    github: Github,
+) -> LDDocument:
+    """Retrieve JSON description of a GitHub repo."""
+    rich.print(f'Downloading: {repository_name}')
+    repo = github.get_repo(repository_name)
+    description = repo.raw_data
+
+    description.update({
+        'releases': retrieve_releases(repo),
+        '@id': description['html_url'],
+    })
+
+    # GitHub does not know the license, so we will not export it.
+    spdx_id = description['license']['spdx_id']
+    if spdx_id == 'NOASSERTION':
+        description.pop('license')
+
+    return description
+
+
+def download_repository(
+    repository_name,
+    github,
+    target_dir,
+):
+    repository_description = retrieve_repository_description(
+        repository_name=repository_name,
+        github=github,
+    )
+
+    file_name = repository_description['full_name'].replace('/', '__')
+    (target_dir / f'{file_name}.json').write_text(json.dumps(
+        repository_description,
+        indent=2,
+    ))
+
+
 @app.command(name='update')
 def github_cli():
     """Update GitHub information."""
@@ -73,7 +128,7 @@ def github_cli():
 
     repo_names = set(filter(bool, map(extract_repo_name, urls)))
 
-    gh = Github()
+    github = Github(os.getenv('GITHUB_TOKEN'))
 
     docs_dir = Path.cwd() / 'docs'
 
@@ -87,7 +142,7 @@ def github_cli():
     target_dir.mkdir(parents=True, exist_ok=True)
     (target_dir / 'context.json').write_text(json.dumps(
         {
-            '@import': 'github',
+            '@import': 'gh-auto',
 
             # FIXME: See docs/decisions/0010-context-application-order.md
             '@vocab': str(GH),
@@ -95,27 +150,11 @@ def github_cli():
         indent=2,
     ))
 
-    for repo_name in repo_names:
-        rich.print(f'Downloading: {repo_name}')
-        try:
-            repo = gh.get_repo(repo_name)
-        except UnknownObjectException:
-            logger.error(
-                '%s is not a valid GitHub repository name.',
-                repo_name,
-            )
-            continue
-
-        formatted_data = repo.raw_data
-        formatted_data['@id'] = repo.html_url
-
-        # GitHub does not know the license, so we will not export it.
-        spdx_id = formatted_data['license']['spdx_id']
-        if spdx_id == 'NOASSERTION':
-            formatted_data.pop('license')
-
-        file_name = repo.full_name.replace('/', '__')
-        (target_dir / f'{file_name}.json').write_text(json.dumps(
-            formatted_data,
-            indent=2,
-        ))
+    ThreadPoolExecutor(max_workers=5).map(
+        partial(
+            download_repository,
+            github=github,
+            target_dir=target_dir,
+        ),
+        repo_names,
+    )
